###-----------------------------------------------------------------------------
#
#	 Name : ContextMenuMenus.rb
#
# Description : Adds Menus onto Context Menu
#
#      Author : TIG (c) 12/2005
#
#       Usage : Right mouse-click to get context-menu and select the menu/tool required off the list.
#		The default list is all of available Menu items.
#		To remove a tool/action from the list put ### in front of its line...
#
#        Type : Context Menu Tool
#
#     Version : 1.0  01/12/05	First issue.
#		1.1  01/02/05	Duplicated Zoom Window removed.
#		1.2  17/12/05	Shadow and Xray toggles added.
#   1.3  09/01/07 v6 Ruby Help added,
#
###------------------------------------------------------------------------------

require 'sketchup.rb'

### #################################################################

if( not file_loaded?("ContextMenuMenus.rb") )

   UI.add_context_menu_handler do | menu |

      menu.add_separator ### this adds a seperator line

        submenus=menu.add_submenu("Menu Items...") ### adds the submenus

      submenu1=submenus.add_submenu("Edit...") ### adds the submenus for the items that follow
      submenu2=submenus.add_submenu("View...")
      submenu3=submenus.add_submenu("Camera...")
      submenu4=submenus.add_submenu("Draw...")
      submenu5=submenus.add_submenu("Tools...")
      submenu6=submenus.add_submenu("Window...")
      submenu8=submenus.add_submenu("Help...")

      submenu1.add_item("Undo") { Sketchup.send_action "editUndo:" }
      submenu1.add_item("Redo") { Sketchup.send_action "editRedo:" }
      submenu1.add_item("Hide") { Sketchup.send_action "editHide:" }
      submenu1.add_item("Unhide") { Sketchup.send_action "editUnhide:" }

      submenu2.add_item("Hidden Geometry (toggle)") { Sketchup.send_action "viewShowHidden:" }
      submenu2.add_item("Axes (toggle)") { Sketchup.send_action "viewShowAxes:" }
        submenu2.add_separator ### this adds a seperator line
      submenu2.add_item("Shadows (toggle)") { if Sketchup.active_model.shadow_info["DisplayShadows"]
  Sketchup.active_model.shadow_info["DisplayShadows"]=false
else
  Sketchup.active_model.shadow_info["DisplayShadows"]=true
end }
      submenu2.add_item("X-ray (toggle)") { if Sketchup.active_model.rendering_options["ModelTransparency"]
  Sketchup.active_model.rendering_options["ModelTransparency"]=false
else
  Sketchup.active_model.rendering_options["ModelTransparency"]=true
end }
         submenu2.add_separator ### this adds a seperator line
      submenu2.add_item("Wireframe") { Sketchup.send_action "renderWireframe:" }
      submenu2.add_item("Hidden Line") { Sketchup.send_action "renderHiddenLine:" }
      submenu2.add_item("Shaded") { Sketchup.send_action "renderShaded:" }
      submenu2.add_item("Shaded With Textures") { Sketchup.send_action "renderTextures:" }
      submenu2.add_item("Monochrome") { Sketchup.send_action "renderMonochrome:" }
        submenu2.add_separator ### this adds a seperator line
      submenu2.add_item("Add Page:Scene") { Sketchup.send_action "pageAdd:" }
      submenu2.add_item("Update Page:Scene") { Sketchup.send_action "pageUpdate:" }
      submenu2.add_item("Delete Page:Scene") { Sketchup.send_action "pageDelete:" }
      submenu2.add_item("Previous Page:Scene") { Sketchup.send_action "pagePrevious:" }
      submenu2.add_item("Next Page:Scene") { Sketchup.send_action "pageNext:" }

      submenu3.add_item("Previous Camera") { Sketchup.send_action "viewUndo:" }
        submenu3.add_separator ### this adds a seperator line
      submenu3.add_item("Top") { Sketchup.send_action "viewTop:" }
      submenu3.add_item("Bottom") { Sketchup.send_action "viewBottom:" }
      submenu3.add_item("Front") { Sketchup.send_action "viewFront:" }
      submenu3.add_item("Back") { Sketchup.send_action "viewBack:" }
      submenu3.add_item("Left") { Sketchup.send_action "viewLeft:" }
      submenu3.add_item("Right") { Sketchup.send_action "viewRight:" }
      submenu3.add_item("Iso") { Sketchup.send_action "viewIso:" }
        submenu3.add_separator ### this adds a seperator line
      submenu3.add_item("Perspective (toggle)") { Sketchup.send_action "viewPerspective:" }
      submenu3.add_item("Field of View") { Sketchup.send_action "selectFieldOfViewTool:" }
        submenu3.add_separator ### this adds a seperator line
      submenu3.add_item("Orbit") { Sketchup.send_action "selectOrbitTool:" }
      submenu3.add_item("Pan") { Sketchup.send_action "selectDollyTool:" }
      submenu3.add_item("Zoom") { Sketchup.send_action "selectZoomTool:" }
      submenu3.add_item("Zoom Window") { Sketchup.send_action "selectZoomWindowTool:" } ### v1.1
      submenu3.add_item("Zoom Extents") { Sketchup.send_action "viewZoomExtents:" }
      submenu3.add_item("Zoom Selection") { Sketchup.send_action "viewZoomToSelection:" }
        submenu3.add_separator ### this adds a seperator line
      submenu3.add_item("Position Camera") { Sketchup.send_action "selectPositionCameraTool:" }
      submenu3.add_item("Walk") { Sketchup.send_action "selectWalkTool:" }
      submenu3.add_item("Look Around") { Sketchup.send_action "selectTurnTool:" }
 
      submenu4.add_item("Line") { Sketchup.send_action "selectLineTool:" }
      submenu4.add_item("Arc") { Sketchup.send_action "selectArcTool:" }
      submenu4.add_item("Freehand") { Sketchup.send_action "selectFreehandTool:" }
      submenu4.add_item("Rectangle") { Sketchup.send_action "selectRectangleTool:" }
      submenu4.add_item("Circle") { Sketchup.send_action "selectCircleTool:" }
      submenu4.add_item("Polygon") { Sketchup.send_action "selectPolygonTool:" }

      submenu5.add_item("Select") { Sketchup.send_action "selectSelectionTool:" }
      submenu5.add_item("Eraser") { Sketchup.send_action "selectEraseTool:" }
      submenu5.add_item("Paint Bucket") { Sketchup.send_action "selectPaintTool:" }
      submenu5.add_item("Move") { Sketchup.send_action "selectMoveTool:" }
      submenu5.add_item("Rotate") { Sketchup.send_action "selectRotateTool:" }
      submenu5.add_item("Scale") { Sketchup.send_action "selectScaleTool:" }
      submenu5.add_item("PushPull") { Sketchup.send_action "selectPushPullTool:" }
      submenu5.add_item("Follow Me") { Sketchup.send_action "selectExtrudeTool:" }
      submenu5.add_item("Offset") { Sketchup.send_action "selectOffsetTool:" }
      submenu5.add_item("Tape Measure") { Sketchup.send_action "selectMeasureTool:" }
      submenu5.add_item("Protractor") { Sketchup.send_action "selectProtractorTool:" }
      submenu5.add_item("Axes") { Sketchup.send_action "selectAxisTool:" }
      submenu5.add_item("Dimensions") { Sketchup.send_action "selectDimensionTool:" }
      submenu5.add_item("Text") { Sketchup.send_action "selectTextTool:" }
      submenu5.add_item("Section Plane") { Sketchup.send_action "selectSectionPlaneTool:" }

      submenu6.add_item("Ruby Console") { Sketchup.send_action "showRubyPanel:" }

      ###submenu8.add_item("SketchUp Help") { UI.openURL(Sketchup.find_support_file "SketchUp.chm", "") }
      submenu8.add_item("Quick Reference") { UI.openURL(Sketchup.find_support_file "QuickReferenceCard.pdf", "") }
      submenu8.add_item("SketchUp Website") { UI.openURL("http://www.sketchup.com/") }
      submenu8.add_item("Ruby Help") {UI.openURL("http://download.sketchup.com/sketchuphelp/gsu6_ruby/Docs/index.html") }

      ### remember you can add hashes in front of items to remove from list...

   end #do

end #if

#-----------------------------------------------------------------------------
file_loaded("ContextMenuMenus.rb")
###